@@ -1,6 +1,7 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from typing import Any, List, Optional
+
+from typing import Any
 from ocp_resources.resource import Resource
 
 
@@ -13,12 +14,12 @@ class Namespace(Resource):
 
     def __init__(
         self,
-        finalizers: Optional[List[Any]] = None,
+        finalizers: list[Any] | None = None,
         **kwargs: Any,
     ) -> None:
-        """
+        r"""
         Args:
-            finalizers (List[Any]): Finalizers is an opaque list of values that must be empty to
+            finalizers (list[Any]): Finalizers is an opaque list of values that must be empty to
               permanently remove object from storage. More info:
               https://kubernetes.io/docs/tasks/administer-cluster/namespaces/
 
@@ -34,7 +35,7 @@ class Namespace(Resource):
             self.res["spec"] = {}
             _spec = self.res["spec"]
 
-            if self.finalizers:
+            if self.finalizers is not None:
                 _spec["finalizers"] = self.finalizers
 
     # End of generated code
