@@ -501,6 +501,7 @@ class Resource(ResourceConstants):
         IMAGEREGISTRY_OPERATOR_OPENSHIFT_IO: str = "imageregistry.operator.openshift.io"
         INSTANCETYPE_KUBEVIRT_IO: str = "instancetype.kubevirt.io"
         INTEGREATLY_ORG: str = "integreatly.org"
+        JAEGERTRACING_IO = "jaegertracing.io"
         K8S_CNI_CNCF_IO: str = "k8s.cni.cncf.io"
         K8S_MARIADB_COM: str = "k8s.mariadb.com"
         K8S_OVN_ORG: str = "k8s.ovn.org"
@@ -530,6 +531,7 @@ class Resource(ResourceConstants):
         NODEMAINTENANCE_KUBEVIRT_IO: str = "nodemaintenance.kubevirt.io"
         OBSERVABILITY_OPEN_CLUSTER_MANAGEMENT_IO: str = "observability.open-cluster-management.io"
         OCS_OPENSHIFT_IO: str = "ocs.openshift.io"
+        OPENTELEMETRY_IO: str = "opentelemetry.io"
         OPERATOR_AUTHORINO_KUADRANT_IO: str = "operator.authorino.kuadrant.io"
         OPERATOR_OPEN_CLUSTER_MANAGEMENT_IO: str = "operator.open-cluster-management.io"
         OPERATOR_OPENSHIFT_IO: str = "operator.openshift.io"
