@@ -1,25 +1,25 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from typing import Any, Dict, Optional
+
+from typing import Any
 from ocp_resources.resource import NamespacedResource, MissingRequiredArgumentError
 
 
 class ServiceMeshMember(NamespacedResource):
     """
-    ServiceMeshMember provide a way for administrators to delegate permissions to add projects to a service mesh,
-    even when the respective users do not have direct access to the service mesh project or member roll.
+    No field description from API
     """
 
     api_group: str = NamespacedResource.ApiGroup.MAISTRA_IO
 
     def __init__(
         self,
-        control_plane_ref: Optional[Dict[str, Any]] = None,
+        control_plane_ref: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
-        """
+        r"""
         Args:
-            control_plane_ref (Dict[str, Any]): Dict with `ServiceMeshControlPlane` information.
+            control_plane_ref (dict[str, Any]): No field description from API
 
         """
         super().__init__(**kwargs)
@@ -30,12 +30,12 @@ class ServiceMeshMember(NamespacedResource):
         super().to_dict()
 
         if not self.kind_dict and not self.yaml_file:
-            if not all([
-                self.control_plane_ref,
-            ]):
-                raise MissingRequiredArgumentError(argument="control_plane_ref")
+            if self.control_plane_ref is None:
+                raise MissingRequiredArgumentError(argument="self.control_plane_ref")
 
             self.res["spec"] = {}
             _spec = self.res["spec"]
 
             _spec["controlPlaneRef"] = self.control_plane_ref
+
+    # End of generated code
