@@ -1,6 +1,7 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from typing import Any, Dict, Optional
+
+from typing import Any
 from ocp_resources.resource import NamespacedResource, MissingRequiredArgumentError
 
 
@@ -8,7 +9,6 @@ class VirtualMachineInstancePreset(NamespacedResource):
     """
         Deprecated for removal in v2, please use VirtualMachineInstanceType and VirtualMachinePreference instead.
 
-
     VirtualMachineInstancePreset defines a VMI spec.domain to be applied to all VMIs that match the provided label selector
     More info: https://kubevirt.io/user-guide/virtual_machines/presets/#overrides
     """
@@ -17,16 +17,16 @@ class VirtualMachineInstancePreset(NamespacedResource):
 
     def __init__(
         self,
-        domain: Optional[Dict[str, Any]] = None,
-        selector: Optional[Dict[str, Any]] = None,
+        domain: dict[str, Any] | None = None,
+        selector: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
-        """
+        r"""
         Args:
-            domain (Dict[str, Any]): Domain is the same object type as contained in
+            domain (dict[str, Any]): Domain is the same object type as contained in
               VirtualMachineInstanceSpec
 
-            selector (Dict[str, Any]): Selector is a label query over a set of VMIs. Required.
+            selector (dict[str, Any]): Selector is a label query over a set of VMIs. Required.
 
         """
         super().__init__(**kwargs)
@@ -38,7 +38,7 @@ class VirtualMachineInstancePreset(NamespacedResource):
         super().to_dict()
 
         if not self.kind_dict and not self.yaml_file:
-            if not self.selector:
+            if self.selector is None:
                 raise MissingRequiredArgumentError(argument="self.selector")
 
             self.res["spec"] = {}
@@ -46,7 +46,7 @@ class VirtualMachineInstancePreset(NamespacedResource):
 
             _spec["selector"] = self.selector
 
-            if self.domain:
+            if self.domain is not None:
                 _spec["domain"] = self.domain
 
     # End of generated code
